==> jc-1.4.0.tar.gz: java/util/LinkedHashSet.h <==
// public class java.util.LinkedHashSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 3c285c721478414d java_util_HashSet
// @dep_class 70388a5394f54659 java_util_LinkedHashSet

// header file dependencies
// @dep_header java_util_HashSet

#include "java/util/HashSet.h"

#ifndef _JC_java_util_LinkedHashSet_H_
#define _JC_java_util_LinkedHashSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_util_LinkedHashSet$sub_refs	_jc_java_util_LinkedHashSet$sub_refs;
typedef struct _jc_java_util_LinkedHashSet$sub_nonrefs	_jc_java_util_LinkedHashSet$sub_nonrefs;
typedef struct _jc_java_util_LinkedHashSet$refs	_jc_java_util_LinkedHashSet$refs;
typedef struct _jc_java_util_LinkedHashSet$nonrefs	_jc_java_util_LinkedHashSet$nonrefs;
typedef struct _jc_java_util_LinkedHashSet$object	_jc_java_util_LinkedHashSet$object;

typedef struct _jc_java_util_LinkedHashSet$fields_struct	_jc_java_util_LinkedHashSet$fields_struct;
typedef const struct _jc_java_util_LinkedHashSet$vmethods	_jc_java_util_LinkedHashSet$vmethods;
typedef const struct _jc_java_util_LinkedHashSet$vtable	_jc_java_util_LinkedHashSet$vtable;
typedef const struct _jc_java_util_LinkedHashSet$vtype	_jc_java_util_LinkedHashSet$vtype;

// Class fields structure
struct _jc_java_util_LinkedHashSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_LinkedHashSet$fields_struct _jc_java_util_LinkedHashSet$class_fields;

// Constructors
extern void _jc_java_util_LinkedHashSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_LinkedHashSet$object *);
extern void _jc_java_util_LinkedHashSet$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint);
extern void _jc_java_util_LinkedHashSet$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat);
extern void _jc_java_util_LinkedHashSet$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_util_HashMap$object *_jc_java_util_LinkedHashSet$method$init$ecdc2f156f5d097b(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat);

// Virtual method descriptors
extern _jc_method _jc_java_util_LinkedHashSet$method_info$init$ecdc2f156f5d097b;

// Virtual methods structure
struct _jc_java_util_LinkedHashSet$vmethods {
	struct _jc_java_util_HashMap$object	*(*init$ecdc2f156f5d097b)(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat);
};

// Vtable
struct _jc_java_util_LinkedHashSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_HashSet$vmethods	java_util_HashSet;
	_jc_java_util_LinkedHashSet$vmethods	java_util_LinkedHashSet;
};

// Vtype
struct _jc_java_util_LinkedHashSet$vtype {
	_jc_type			type;
	_jc_java_util_LinkedHashSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedHashSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_LinkedHashSet$refs {
    _jc_java_util_LinkedHashSet$sub_refs	java_util_LinkedHashSet;
    _jc_java_util_HashSet$sub_refs	java_util_HashSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedHashSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedHashSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_HashSet$sub_nonrefs	java_util_HashSet;
    _jc_java_util_LinkedHashSet$sub_nonrefs	java_util_LinkedHashSet;
};

// Object instance structure
struct _jc_java_util_LinkedHashSet$object {
	_jc_java_util_LinkedHashSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedHashSet$vtype	*vtype;
	_jc_java_util_LinkedHashSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedHashSet$vtype _jc_java_util_LinkedHashSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedHashSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedHashSet$class_object;

#endif	/* _JC_java_util_LinkedHashSet_H_ */

==> jc-1.4.6.tar.gz: java/util/LinkedHashSet.h <==
// public class java.util.LinkedHashSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8ea716c64b77f8eb java_util_AbstractCollection
// @dep_class ca427569b5b2f804 java_util_AbstractSet
// @dep_class 3c285c721478414d java_util_HashSet
// @dep_class 70388a5394f54659 java_util_LinkedHashSet

// header file dependencies
// @dep_header java_util_HashSet

#include "java/util/HashSet.h"

#ifndef _JC_java_util_LinkedHashSet_H_
#define _JC_java_util_LinkedHashSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_HashMap$object;

// Typedefs
typedef struct _jc_java_util_LinkedHashSet$sub_refs	_jc_java_util_LinkedHashSet$sub_refs;
typedef struct _jc_java_util_LinkedHashSet$sub_nonrefs	_jc_java_util_LinkedHashSet$sub_nonrefs;
typedef struct _jc_java_util_LinkedHashSet$refs	_jc_java_util_LinkedHashSet$refs;
typedef struct _jc_java_util_LinkedHashSet$nonrefs	_jc_java_util_LinkedHashSet$nonrefs;
typedef struct _jc_java_util_LinkedHashSet$object	_jc_java_util_LinkedHashSet$object;

typedef struct _jc_java_util_LinkedHashSet$fields_struct	_jc_java_util_LinkedHashSet$fields_struct;
typedef const struct _jc_java_util_LinkedHashSet$vmethods	_jc_java_util_LinkedHashSet$vmethods;
typedef const struct _jc_java_util_LinkedHashSet$vtable	_jc_java_util_LinkedHashSet$vtable;
typedef const struct _jc_java_util_LinkedHashSet$vtype	_jc_java_util_LinkedHashSet$vtype;

// Class fields structure
struct _jc_java_util_LinkedHashSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_LinkedHashSet$fields_struct _jc_java_util_LinkedHashSet$class_fields;

// Constructors
extern void _jc_java_util_LinkedHashSet$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_LinkedHashSet$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_LinkedHashSet$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_LinkedHashSet$method$_init$7cb044ce4fb0ada8(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat) _JC_JCNI_ATTR;
extern void _jc_java_util_LinkedHashSet$method$_init$f10d3ead4f9e91ce(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_HashMap$object *_jc_java_util_LinkedHashSet$method$init$ecdc2f156f5d097b(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_LinkedHashSet$method_info$init$ecdc2f156f5d097b;

// Virtual methods structure
struct _jc_java_util_LinkedHashSet$vmethods {
	struct _jc_java_util_HashMap$object	*(*init$ecdc2f156f5d097b)(_jc_env *, struct _jc_java_util_LinkedHashSet$object *, jint, jfloat) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_LinkedHashSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractCollection$vmethods	java_util_AbstractCollection;
	_jc_java_util_AbstractSet$vmethods	java_util_AbstractSet;
	_jc_java_util_HashSet$vmethods	java_util_HashSet;
	_jc_java_util_LinkedHashSet$vmethods	java_util_LinkedHashSet;
};

// Vtype
struct _jc_java_util_LinkedHashSet$vtype {
	_jc_type			type;
	_jc_java_util_LinkedHashSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedHashSet$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_LinkedHashSet$refs {
    _jc_java_util_LinkedHashSet$sub_refs	java_util_LinkedHashSet;
    _jc_java_util_HashSet$sub_refs	java_util_HashSet;
    _jc_java_util_AbstractSet$sub_refs	java_util_AbstractSet;
    _jc_java_util_AbstractCollection$sub_refs	java_util_AbstractCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedHashSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedHashSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractCollection$sub_nonrefs	java_util_AbstractCollection;
    _jc_java_util_AbstractSet$sub_nonrefs	java_util_AbstractSet;
    _jc_java_util_HashSet$sub_nonrefs	java_util_HashSet;
    _jc_java_util_LinkedHashSet$sub_nonrefs	java_util_LinkedHashSet;
};

// Object instance structure
struct _jc_java_util_LinkedHashSet$object {
	_jc_java_util_LinkedHashSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedHashSet$vtype	*vtype;
	_jc_java_util_LinkedHashSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedHashSet$vtype _jc_java_util_LinkedHashSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedHashSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedHashSet$class_object;

#endif	/* _JC_java_util_LinkedHashSet_H_ */
